@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.9) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.3.10) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/armv6-netbsdelf-eabihf")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "9"
-  CONFIG["PATCHLEVEL"] = "170"
+  CONFIG["TEENY"] = "10"
+  CONFIG["PATCHLEVEL"] = "183"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/pkg")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)33"
   CONFIG["RUBY_SO_NAME"] = "ruby33"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.9.pc"
+  CONFIG["ruby_pc"] = "ruby-3.3.10.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--disable-dtrace' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3.0' '--with-ruby-pc=ruby-3.3.9.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'CXXFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--disable-dtrace' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3.0' '--with-ruby-pc=ruby-3.3.10.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include -Dz_off_t=long' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include -Dz_off_t=long' 'CXXFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include -Dz_off_t=long'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -170,7 +170,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb4 20200810) 7.5.0\nCopyright (C) 2017 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb3 20231008) 10.5.0\nCopyright (C) 2020 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -179,11 +179,11 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include"
+  CONFIG["CXXFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include -Dz_off_t=long"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-I/usr/include -I/usr/pkg/include $(DEFS) $(cppflags)"
+  CONFIG["CPPFLAGS"] = "-I/usr/include -I/usr/pkg/include -Dz_off_t=long $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread -Wl,-export-dynamic -Wl,--no-as-needed"
-  CONFIG["CFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include -fPIC -pipe"
+  CONFIG["CFLAGS"] = "-O2 -pthread -I/usr/include -I/usr/pkg/include -Dz_off_t=long -fPIC -pipe"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["OBJDUMP"] = "objdump"
